@@ -1,13 +1,13 @@
 # Ultralytics YOLO 🚀, AGPL-3.0 license
 
-__version__ = "8.2.53"
+__version__ = "8.3.21"
 
 import os
 
-# Set ENV Variables (place before imports)
-os.environ["OMP_NUM_THREADS"] = "1"  # reduce CPU utilization during training
+# Set ENV variables (place before imports)
+if not os.environ.get("OMP_NUM_THREADS"):
+    os.environ["OMP_NUM_THREADS"] = "1"  # default for reduced CPU utilization during training
 
-from ultralytics.data.explorer.explorer import Explorer
 from ultralytics.models import NAS, RTDETR, SAM, YOLO, FastSAM, YOLOWorld
 from ultralytics.utils import ASSETS, SETTINGS
 from ultralytics.utils.checks import check_yolo as checks
@@ -26,5 +26,4 @@ __all__ = (
     "checks",
     "download",
     "settings",
-    "Explorer",
 )
